##Coptic Transliteration Tool

The vision of this project is to provide an easy, bulk transliteration service between Coptic and Latin script. The primary use case (Coptic --> Latin script) is to allow English speakers who do not read Coptic to follow along with church services by offering transliterated text with accurate and transparent pronunciations.

##The transliteration script

1) accepts a single text file as input
2) transforms a copy of the input file into Latin script using rule-based character mappings (implemented in Python)
3) outputs the transformed copy of the input file (text file output format)"

##Pre-requisites to run this script

**TODO**

##How to run this script?

**TODO**

##Pronunciation Guide

**TODO**

##References

**TODO**